@@ -9,11 +9,14 @@ package Comics::Plugin::GoneIntoRapture;
 
 use parent qw(Comics::Fetcher::Single);
 
-our $VERSION = "1.00";
+our $VERSION = "1.01";
 
 our $name    = "Gone into Rapture";
 our $url     = "http://goneintorapture.com/";
 
+# Can't get it to work anymore.
+our $disabled = 1;
+
 our $pattern =
   qr{ <figure \s+ class="photo-hires-item"> \s+
       <a .*? > \s*
